==> tencentcloud-sdk-java-3.1.930-sources.jar: com/tencentcloudapi/tcb/v20180608/models/DescribeExtraPkgBillingInfoResponse.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.tcb.v20180608.models;

import com.tencentcloudapi.common.AbstractModel;
import com.tencentcloudapi.common.SSEResponseModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class DescribeExtraPkgBillingInfoResponse extends AbstractModel {

    /**
    * 增值包计费信息列表
    */
    @SerializedName("EnvInfoList")
    @Expose
    private EnvBillingInfoItem [] EnvInfoList;

    /**
    * 增值包数目
    */
    @SerializedName("Total")
    @Expose
    private Long Total;

    /**
    * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
    */
    @SerializedName("RequestId")
    @Expose
    private String RequestId;

    /**
     * Get 增值包计费信息列表 
     * @return EnvInfoList 增值包计费信息列表
     */
    public EnvBillingInfoItem [] getEnvInfoList() {
        return this.EnvInfoList;
    }

    /**
     * Set 增值包计费信息列表
     * @param EnvInfoList 增值包计费信息列表
     */
    public void setEnvInfoList(EnvBillingInfoItem [] EnvInfoList) {
        this.EnvInfoList = EnvInfoList;
    }

    /**
     * Get 增值包数目 
     * @return Total 增值包数目
     */
    public Long getTotal() {
        return this.Total;
    }

    /**
     * Set 增值包数目
     * @param Total 增值包数目
     */
    public void setTotal(Long Total) {
        this.Total = Total;
    }

    /**
     * Get 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。 
     * @return RequestId 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
     */
    public String getRequestId() {
        return this.RequestId;
    }

    /**
     * Set 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
     * @param RequestId 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
     */
    public void setRequestId(String RequestId) {
        this.RequestId = RequestId;
    }

    public DescribeExtraPkgBillingInfoResponse() {
    }

    /**
     * NOTE: Any ambiguous key set via .set("AnyKey", "value") will be a shallow copy,
     *       and any explicit key, i.e Foo, set via .setFoo("value") will be a deep copy.
     */
    public DescribeExtraPkgBillingInfoResponse(DescribeExtraPkgBillingInfoResponse source) {
        if (source.EnvInfoList != null) {
            this.EnvInfoList = new EnvBillingInfoItem[source.EnvInfoList.length];
            for (int i = 0; i < source.EnvInfoList.length; i++) {
                this.EnvInfoList[i] = new EnvBillingInfoItem(source.EnvInfoList[i]);
            }
        }
        if (source.Total != null) {
            this.Total = new Long(source.Total);
        }
        if (source.RequestId != null) {
            this.RequestId = new String(source.RequestId);
        }
    }


    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamArrayObj(map, prefix + "EnvInfoList.", this.EnvInfoList);
        this.setParamSimple(map, prefix + "Total", this.Total);
        this.setParamSimple(map, prefix + "RequestId", this.RequestId);

    }
}

==> tencentcloud-sdk-java-3.1.1157-sources.jar: com/tencentcloudapi/tcb/v20180608/models/DescribeExtraPkgBillingInfoResponse.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.tcb.v20180608.models;

import com.tencentcloudapi.common.AbstractModel;
import com.tencentcloudapi.common.SSEResponseModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class DescribeExtraPkgBillingInfoResponse extends AbstractModel {

    /**
    * 增值包计费信息列表
    */
    @SerializedName("EnvInfoList")
    @Expose
    private EnvBillingInfoItem [] EnvInfoList;

    /**
    * 增值包数目
    */
    @SerializedName("Total")
    @Expose
    private Long Total;

    /**
    * 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
    */
    @SerializedName("RequestId")
    @Expose
    private String RequestId;

    /**
     * Get 增值包计费信息列表 
     * @return EnvInfoList 增值包计费信息列表
     */
    public EnvBillingInfoItem [] getEnvInfoList() {
        return this.EnvInfoList;
    }

    /**
     * Set 增值包计费信息列表
     * @param EnvInfoList 增值包计费信息列表
     */
    public void setEnvInfoList(EnvBillingInfoItem [] EnvInfoList) {
        this.EnvInfoList = EnvInfoList;
    }

    /**
     * Get 增值包数目 
     * @return Total 增值包数目
     */
    public Long getTotal() {
        return this.Total;
    }

    /**
     * Set 增值包数目
     * @param Total 增值包数目
     */
    public void setTotal(Long Total) {
        this.Total = Total;
    }

    /**
     * Get 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。 
     * @return RequestId 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
     */
    public String getRequestId() {
        return this.RequestId;
    }

    /**
     * Set 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
     * @param RequestId 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
     */
    public void setRequestId(String RequestId) {
        this.RequestId = RequestId;
    }

    public DescribeExtraPkgBillingInfoResponse() {
    }

    /**
     * NOTE: Any ambiguous key set via .set("AnyKey", "value") will be a shallow copy,
     *       and any explicit key, i.e Foo, set via .setFoo("value") will be a deep copy.
     */
    public DescribeExtraPkgBillingInfoResponse(DescribeExtraPkgBillingInfoResponse source) {
        if (source.EnvInfoList != null) {
            this.EnvInfoList = new EnvBillingInfoItem[source.EnvInfoList.length];
            for (int i = 0; i < source.EnvInfoList.length; i++) {
                this.EnvInfoList[i] = new EnvBillingInfoItem(source.EnvInfoList[i]);
            }
        }
        if (source.Total != null) {
            this.Total = new Long(source.Total);
        }
        if (source.RequestId != null) {
            this.RequestId = new String(source.RequestId);
        }
    }


    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamArrayObj(map, prefix + "EnvInfoList.", this.EnvInfoList);
        this.setParamSimple(map, prefix + "Total", this.Total);
        this.setParamSimple(map, prefix + "RequestId", this.RequestId);

    }
}
